@@ -542,5 +542,5 @@ if __name__ == "__main__":
         )
 
     # example_fdn(args)
-    example_fdn_accurate_geq(args)
-    # example_fdn_direct(args)
+    # example_fdn_accurate_geq(args)
+    example_fdn_direct(args)
